==> TencentNavKitDocument_7.2.0.zip: TencentNavKitDocument/search/properties_10.js <==
var searchData=
[
  ['rate_0',['rate',['../protocol_t_n_k_audio_player_protocol-p.html#aeded9e873193ea3e9330e20650a124d7',1,'TNKAudioPlayerProtocol-p']]],
  ['reason_1',['reason',['../interface_t_n_k_change_route_msg.html#a52ca2c91fe49d0da0ab61ae5c6d50946',1,'TNKChangeRouteMsg']]],
  ['recommendreason_2',['recommendReason',['../interface_t_n_k_drive_route.html#accfdaf68cf1d7b11625195a1d5335798',1,'TNKDriveRoute::recommendReason()'],['../interface_t_n_k_recommend_route_info.html#a2186ab089de8cf86fb63369f00293877',1,'TNKRecommendRouteInfo::recommendReason()'],['../interface_t_n_k_ride_route.html#aca3b956c119e338f58d3edd1e95fcaf1',1,'TNKRideRoute::recommendReason()'],['../interface_t_n_k_walk_route.html#a410b85658ffdc3ecf5da2064ad7b895e',1,'TNKWalkRoute::recommendReason()']]],
  ['recommendrouteid_3',['recommendRouteID',['../interface_t_n_k_recommend_route_info.html#a4b0252c3590c33c6cae85eddd263bfcf',1,'TNKRecommendRouteInfo']]],
  ['recommendtype_4',['recommendType',['../interface_t_n_k_recommend_route_info.html#a3440e1dd344f835b430ca45fcbd21656',1,'TNKRecommendRouteInfo']]],
  ['remainingdistance_5',['remainingDistance',['../interface_t_n_k_drive_nav_route.html#a7671d75649be10cf6efcd12c9cfd5577',1,'TNKDriveNavRoute::remainingDistance()'],['../interface_t_n_k_highway_facility_item.html#aae62ab5baccaaa25a328214208d881bd',1,'TNKHighwayFacilityItem::remainingDistance()'],['../interface_t_n_k_location.html#a87f42744e0e02b6201ca930f01a2d155',1,'TNKLocation::remainingDistance()'],['../interface_t_n_k_nav_to_way_point_info.html#a44a6be074001a79b36fb6b7be2f6e612',1,'TNKNavToWayPointInfo::remainingDistance()'],['../interface_t_n_k_ride_nav_route.html#aa83f687a5b9ef5557056b06d0b1c4a00',1,'TNKRideNavRoute::remainingDistance()'],['../interface_t_n_k_walk_nav_route.html#aa49cc936358cf193c68e678c46ddf348',1,'TNKWalkNavRoute::remainingDistance()']]],
  ['remainingtime_6',['remainingTime',['../interface_t_n_k_drive_nav_route.html#a8573f45fe1ed35ea43d56e69b42578e3',1,'TNKDriveNavRoute::remainingTime()'],['../interface_t_n_k_location.html#a713f1fc82cad3af773887fab580b06bb',1,'TNKLocation::remainingTime()'],['../interface_t_n_k_nav_to_way_point_info.html#a78f665eaea849487d213cdfaeea5011c',1,'TNKNavToWayPointInfo::remainingTime()'],['../interface_t_n_k_ride_nav_route.html#aab96d43c22bfd2e99986b93ab7cd444d',1,'TNKRideNavRoute::remainingTime()'],['../interface_t_n_k_walk_nav_route.html#a19fb9ddfc528f2539a495f4f99a63f58',1,'TNKWalkNavRoute::remainingTime()']]],
  ['remainingtimeinseconds_7',['remainingTimeInSeconds',['../interface_t_n_k_drive_nav_route.html#a5fa0b33f498befdbef55b927a6a6d895',1,'TNKDriveNavRoute']]],
  ['remaintrafficlightcount_8',['remainTrafficLightCount',['../interface_t_n_k_drive_navigation_data.html#ac66ef793ca9e59f46e2483993bdfcc55',1,'TNKDriveNavigationData::remainTrafficLightCount()'],['../interface_t_n_k_location.html#a58ff0df55b1b82052b1b77955d22837e',1,'TNKLocation::remainTrafficLightCount()'],['../interface_t_n_k_travel_navigation_data.html#a5a640a93eb3be40208effb38cd44da4e',1,'TNKTravelNavigationData::remainTrafficLightCount()']]],
  ['requestid_9',['requestID',['../interface_t_n_k_restore_route_reroute_param.html#aff595373f8e46fa496600884c3ecc089',1,'TNKRestoreRouteRerouteParam']]],
  ['reroutereason_10',['rerouteReason',['../interface_t_n_k_drive_reroute_result.html#ac101ec5130f2b066277ba12977997491',1,'TNKDriveRerouteResult::rerouteReason()'],['../interface_t_n_k_ride_reroute_result.html#a62255e31fc12384bae2b331ffcd214e9',1,'TNKRideRerouteResult::rerouteReason()'],['../interface_t_n_k_walk_reroute_result.html#af01756bb16b9196ae46fccee1fba7fc6',1,'TNKWalkRerouteResult::rerouteReason()']]],
  ['restrictionitem_11',['restrictionItem',['../interface_t_n_k_nav_restriction_item.html#adf8ab7928da669963ec6b03af2b2bd2e',1,'TNKNavRestrictionItem']]],
  ['reversemodeimage_12',['reverseModeImage',['../interface_t_n_k_lane_info.html#a724c498bf2c571870a7bffa207d5c6dd',1,'TNKLaneInfo']]],
  ['roaddir_13',['roadDir',['../interface_t_n_k_nav_road_match_result.html#ac00feea19db1c8a27649651b912dddd4',1,'TNKNavRoadMatchResult']]],
  ['roadgrade_14',['roadGrade',['../interface_t_n_k_nav_road_match_result.html#a853b44920a8e84baa9165576ea554994',1,'TNKNavRoadMatchResult']]],
  ['roadkind_15',['roadKind',['../interface_t_n_k_nav_road_match_result.html#a9f50e694d90c6bc7364790c36a5624ef',1,'TNKNavRoadMatchResult::roadKind()'],['../interface_t_n_k_segment_road_name.html#a0e6ea557e4cf9f1d1d108703e43243e2',1,'TNKSegmentRoadName::roadKind()']]],
  ['roadlength_16',['roadLength',['../interface_t_n_k_segment_item.html#a93f250a3b3fa197818db2bdd9a667288',1,'TNKSegmentItem']]],
  ['roadmatchresult_17',['roadMatchResult',['../interface_t_n_k_pos_match_location.html#a82dcd7dbcddbfd2894244443f6e1be56',1,'TNKPosMatchLocation']]],
  ['roadmatchstatus_18',['roadMatchStatus',['../interface_t_n_k_nav_road_match_result.html#ae3f84ba9af68c3f26461e9ee0edcd9a5',1,'TNKNavRoadMatchResult']]],
  ['roadname_19',['roadName',['../interface_t_n_k_restriction_item.html#a5f85d5028d5444daad9acf79050b228b',1,'TNKRestrictionItem::roadName()'],['../interface_t_n_k_segment_road_name.html#a72574f248be7813857a61cab496fb72a',1,'TNKSegmentRoadName::roadName()'],['../interface_t_n_k_segment_item.html#aa659460549abea3158abba160840549a',1,'TNKSegmentItem::roadName()']]],
  ['roadtype_20',['roadType',['../interface_t_n_k_parallel_road_reroute_param.html#afa11a06deeb5636d0736476235e4d4d1',1,'TNKParallelRoadRerouteParam']]],
  ['routeconfig_21',['routeConfig',['../interface_t_n_k_base_nav_view.html#a61b3e83fb59d47a933033e93219cb14d',1,'TNKBaseNavView']]],
  ['routeexplainitems_22',['routeExplainItems',['../interface_t_n_k_drive_route.html#aae20faa889b3abadb5a90d62024632cd',1,'TNKDriveRoute']]],
  ['routeid_23',['routeID',['../interface_t_n_k_nav_start_fail_info.html#aa9eaa3cac461007b0eb75a9de3623588',1,'TNKNavStartFailInfo::routeID()'],['../interface_t_n_k_drive_route.html#a74349b9346cd18079e41a28de8c4d9cb',1,'TNKDriveRoute::routeID()'],['../interface_t_n_k_location.html#a343a6cd679f13c888d3ae06b2ce3c7c4',1,'TNKLocation::routeID()'],['../interface_t_n_k_restore_route_reroute_param.html#a42c07d371f477eced1916eb0bb2d446b',1,'TNKRestoreRouteRerouteParam::routeID()'],['../interface_t_n_k_ride_route.html#a6d9e901735409fa7669ffa945d9d686e',1,'TNKRideRoute::routeID()'],['../interface_t_n_k_walk_route.html#a0204d3aa6b55e738c62ecc9d935432f0',1,'TNKWalkRoute::routeID()']]],
  ['routeplancachesize_24',['routePlanCacheSize',['../interface_t_n_k_drive_nav_manager.html#af0be6b7417ea7df0986d9b692e3580ce',1,'TNKDriveNavManager']]],
  ['routepoint_25',['routePoint',['../interface_t_n_k_nav_camera_info.html#a64e1147a846a16c6e2622346290ec589',1,'TNKNavCameraInfo::routePoint()'],['../interface_t_n_k_restriction_item.html#af94bf7d7ce36a7b61cafe35bcc3a253b',1,'TNKRestrictionItem::routePoint()'],['../interface_t_n_k_traffic_light_countdown_msg.html#a0271f2d6ddaf5e98e2123716ef0db176',1,'TNKTrafficLightCountdownMsg::routePoint()']]],
  ['routepoints_26',['routePoints',['../interface_t_n_k_drive_route.html#a478319336f5427261bfd7eea2b741495',1,'TNKDriveRoute::routePoints()'],['../interface_t_n_k_ride_route.html#afd18539a61d1fa70a37f6506ff1c1d85',1,'TNKRideRoute::routePoints()'],['../interface_t_n_k_traffic_jam_info.html#a9f4b94833575b0b0606822b8081c0084',1,'TNKTrafficJamInfo::routePoints()'],['../interface_t_n_k_walk_route.html#a7b14a86193d5329fd1912f119902fb0d',1,'TNKWalkRoute::routePoints()']]],
  ['routepointsisreroutesearch_27',['routePointsIsReRouteSearch',['../interface_t_n_k_drive_route_search_option.html#a1fb61bf69dbf9424250acd9e553719e3',1,'TNKDriveRouteSearchOption']]],
  ['routepointsissearch_28',['routePointsIsSearch',['../interface_t_n_k_drive_route_search_option.html#affed1513cbc0717680539f027b9be230',1,'TNKDriveRouteSearchOption']]],
  ['routepointslocations_29',['routePointsLocations',['../interface_t_n_k_drive_route_search_option.html#ac080ed83fddd7bdb6accd7578931a61d',1,'TNKDriveRouteSearchOption']]],
  ['routes_30',['routes',['../interface_t_n_k_drive_route_search_result.html#a8ef0c0261e441f9108b0b6e8f997a150',1,'TNKDriveRouteSearchResult::routes()'],['../interface_t_n_k_ride_route_search_result.html#ae9ac880da356fd3a1fd25e72e1e3772f',1,'TNKRideRouteSearchResult::routes()'],['../interface_t_n_k_walk_route_search_result.html#aa8df575cd9c98bd1ba4b23fbc5322082',1,'TNKWalkRouteSearchResult::routes()']]],
  ['routetrafficitems_31',['routeTrafficItems',['../interface_t_n_k_drive_route.html#a70f241a0d81d5e518f5f3bb05bde7a09',1,'TNKDriveRoute']]],
  ['routetrafficlighthidden_32',['routeTrafficLightHidden',['../interface_t_n_k_drive_nav_view.html#a319172c4389768eaea40497ac10fa3bb',1,'TNKDriveNavView::routeTrafficLightHidden()'],['../interface_t_n_k_travel_nav_view.html#ab00a5d3bdb8cca1315797bb8bff14644',1,'TNKTravelNavView::routeTrafficLightHidden()']]],
  ['running_33',['running',['../interface_t_n_k_base_nav_manager.html#aefc6f278f748cf4c8d61a25c5095cdc3',1,'TNKBaseNavManager']]]
];

==> TencentNavKitDocument_7.3.3.zip: TencentNavKitDocument/search/properties_10.js <==
var searchData=
[
  ['rate_0',['rate',['../protocol_t_n_k_audio_player_protocol-p.html#aeded9e873193ea3e9330e20650a124d7',1,'TNKAudioPlayerProtocol-p']]],
  ['reason_1',['reason',['../interface_t_n_k_change_route_msg.html#a52ca2c91fe49d0da0ab61ae5c6d50946',1,'TNKChangeRouteMsg']]],
  ['recommendreason_2',['recommendReason',['../interface_t_n_k_drive_route.html#accfdaf68cf1d7b11625195a1d5335798',1,'TNKDriveRoute::recommendReason()'],['../interface_t_n_k_recommend_route_info.html#a2186ab089de8cf86fb63369f00293877',1,'TNKRecommendRouteInfo::recommendReason()'],['../interface_t_n_k_ride_route.html#aca3b956c119e338f58d3edd1e95fcaf1',1,'TNKRideRoute::recommendReason()'],['../interface_t_n_k_walk_route.html#a410b85658ffdc3ecf5da2064ad7b895e',1,'TNKWalkRoute::recommendReason()']]],
  ['recommendrouteid_3',['recommendRouteID',['../interface_t_n_k_recommend_route_info.html#a4b0252c3590c33c6cae85eddd263bfcf',1,'TNKRecommendRouteInfo']]],
  ['recommendtype_4',['recommendType',['../interface_t_n_k_recommend_route_info.html#a3440e1dd344f835b430ca45fcbd21656',1,'TNKRecommendRouteInfo']]],
  ['remainingdistance_5',['remainingDistance',['../interface_t_n_k_drive_nav_route.html#a7671d75649be10cf6efcd12c9cfd5577',1,'TNKDriveNavRoute::remainingDistance()'],['../interface_t_n_k_highway_facility_item.html#aae62ab5baccaaa25a328214208d881bd',1,'TNKHighwayFacilityItem::remainingDistance()'],['../interface_t_n_k_location.html#a87f42744e0e02b6201ca930f01a2d155',1,'TNKLocation::remainingDistance()'],['../interface_t_n_k_nav_to_way_point_info.html#a44a6be074001a79b36fb6b7be2f6e612',1,'TNKNavToWayPointInfo::remainingDistance()'],['../interface_t_n_k_ride_nav_route.html#aa83f687a5b9ef5557056b06d0b1c4a00',1,'TNKRideNavRoute::remainingDistance()'],['../interface_t_n_k_walk_nav_route.html#aa49cc936358cf193c68e678c46ddf348',1,'TNKWalkNavRoute::remainingDistance()']]],
  ['remainingtime_6',['remainingTime',['../interface_t_n_k_drive_nav_route.html#a8573f45fe1ed35ea43d56e69b42578e3',1,'TNKDriveNavRoute::remainingTime()'],['../interface_t_n_k_location.html#a713f1fc82cad3af773887fab580b06bb',1,'TNKLocation::remainingTime()'],['../interface_t_n_k_nav_to_way_point_info.html#a78f665eaea849487d213cdfaeea5011c',1,'TNKNavToWayPointInfo::remainingTime()'],['../interface_t_n_k_ride_nav_route.html#aab96d43c22bfd2e99986b93ab7cd444d',1,'TNKRideNavRoute::remainingTime()'],['../interface_t_n_k_walk_nav_route.html#a19fb9ddfc528f2539a495f4f99a63f58',1,'TNKWalkNavRoute::remainingTime()']]],
  ['remainingtimeinseconds_7',['remainingTimeInSeconds',['../interface_t_n_k_drive_nav_route.html#a5fa0b33f498befdbef55b927a6a6d895',1,'TNKDriveNavRoute']]],
  ['remaintrafficlightcount_8',['remainTrafficLightCount',['../interface_t_n_k_drive_navigation_data.html#ac66ef793ca9e59f46e2483993bdfcc55',1,'TNKDriveNavigationData::remainTrafficLightCount()'],['../interface_t_n_k_location.html#a58ff0df55b1b82052b1b77955d22837e',1,'TNKLocation::remainTrafficLightCount()'],['../interface_t_n_k_travel_navigation_data.html#a5a640a93eb3be40208effb38cd44da4e',1,'TNKTravelNavigationData::remainTrafficLightCount()']]],
  ['requestid_9',['requestID',['../interface_t_n_k_restore_route_reroute_param.html#aff595373f8e46fa496600884c3ecc089',1,'TNKRestoreRouteRerouteParam']]],
  ['reroutereason_10',['rerouteReason',['../interface_t_n_k_drive_reroute_result.html#ac101ec5130f2b066277ba12977997491',1,'TNKDriveRerouteResult::rerouteReason()'],['../interface_t_n_k_ride_reroute_result.html#a62255e31fc12384bae2b331ffcd214e9',1,'TNKRideRerouteResult::rerouteReason()'],['../interface_t_n_k_walk_reroute_result.html#af01756bb16b9196ae46fccee1fba7fc6',1,'TNKWalkRerouteResult::rerouteReason()']]],
  ['restrictionitem_11',['restrictionItem',['../interface_t_n_k_nav_restriction_item.html#adf8ab7928da669963ec6b03af2b2bd2e',1,'TNKNavRestrictionItem']]],
  ['reversemodeimage_12',['reverseModeImage',['../interface_t_n_k_lane_info.html#a724c498bf2c571870a7bffa207d5c6dd',1,'TNKLaneInfo']]],
  ['roaddir_13',['roadDir',['../interface_t_n_k_nav_road_match_result.html#ac00feea19db1c8a27649651b912dddd4',1,'TNKNavRoadMatchResult']]],
  ['roadgrade_14',['roadGrade',['../interface_t_n_k_nav_road_match_result.html#a853b44920a8e84baa9165576ea554994',1,'TNKNavRoadMatchResult']]],
  ['roadkind_15',['roadKind',['../interface_t_n_k_nav_road_match_result.html#a9f50e694d90c6bc7364790c36a5624ef',1,'TNKNavRoadMatchResult::roadKind()'],['../interface_t_n_k_segment_road_name.html#a0e6ea557e4cf9f1d1d108703e43243e2',1,'TNKSegmentRoadName::roadKind()']]],
  ['roadlength_16',['roadLength',['../interface_t_n_k_segment_item.html#a93f250a3b3fa197818db2bdd9a667288',1,'TNKSegmentItem']]],
  ['roadmatchresult_17',['roadMatchResult',['../interface_t_n_k_pos_match_location.html#a82dcd7dbcddbfd2894244443f6e1be56',1,'TNKPosMatchLocation']]],
  ['roadmatchstatus_18',['roadMatchStatus',['../interface_t_n_k_nav_road_match_result.html#ae3f84ba9af68c3f26461e9ee0edcd9a5',1,'TNKNavRoadMatchResult']]],
  ['roadname_19',['roadName',['../interface_t_n_k_restriction_item.html#a5f85d5028d5444daad9acf79050b228b',1,'TNKRestrictionItem::roadName()'],['../interface_t_n_k_ride_navigation_brief_info.html#a3e648896151f388bf1cdb53b12a8e65a',1,'TNKRideNavigationBriefInfo::roadName()'],['../interface_t_n_k_segment_road_name.html#a72574f248be7813857a61cab496fb72a',1,'TNKSegmentRoadName::roadName()'],['../interface_t_n_k_segment_item.html#aa659460549abea3158abba160840549a',1,'TNKSegmentItem::roadName()']]],
  ['roadtype_20',['roadType',['../interface_t_n_k_parallel_road_reroute_param.html#afa11a06deeb5636d0736476235e4d4d1',1,'TNKParallelRoadRerouteParam']]],
  ['routeconfig_21',['routeConfig',['../interface_t_n_k_base_nav_view.html#a61b3e83fb59d47a933033e93219cb14d',1,'TNKBaseNavView']]],
  ['routeexplainitems_22',['routeExplainItems',['../interface_t_n_k_drive_route.html#aae20faa889b3abadb5a90d62024632cd',1,'TNKDriveRoute']]],
  ['routeid_23',['routeID',['../interface_t_n_k_nav_start_fail_info.html#aa9eaa3cac461007b0eb75a9de3623588',1,'TNKNavStartFailInfo::routeID()'],['../interface_t_n_k_drive_route.html#a74349b9346cd18079e41a28de8c4d9cb',1,'TNKDriveRoute::routeID()'],['../interface_t_n_k_location.html#a343a6cd679f13c888d3ae06b2ce3c7c4',1,'TNKLocation::routeID()'],['../interface_t_n_k_restore_route_reroute_param.html#a42c07d371f477eced1916eb0bb2d446b',1,'TNKRestoreRouteRerouteParam::routeID()'],['../interface_t_n_k_ride_route.html#a6d9e901735409fa7669ffa945d9d686e',1,'TNKRideRoute::routeID()'],['../interface_t_n_k_walk_route.html#a0204d3aa6b55e738c62ecc9d935432f0',1,'TNKWalkRoute::routeID()']]],
  ['routeplancachesize_24',['routePlanCacheSize',['../interface_t_n_k_drive_nav_manager.html#af0be6b7417ea7df0986d9b692e3580ce',1,'TNKDriveNavManager']]],
  ['routepoint_25',['routePoint',['../interface_t_n_k_nav_camera_info.html#a64e1147a846a16c6e2622346290ec589',1,'TNKNavCameraInfo::routePoint()'],['../interface_t_n_k_restriction_item.html#af94bf7d7ce36a7b61cafe35bcc3a253b',1,'TNKRestrictionItem::routePoint()'],['../interface_t_n_k_traffic_light_countdown_msg.html#a0271f2d6ddaf5e98e2123716ef0db176',1,'TNKTrafficLightCountdownMsg::routePoint()']]],
  ['routepoints_26',['routePoints',['../interface_t_n_k_drive_route.html#a478319336f5427261bfd7eea2b741495',1,'TNKDriveRoute::routePoints()'],['../interface_t_n_k_ride_route.html#afd18539a61d1fa70a37f6506ff1c1d85',1,'TNKRideRoute::routePoints()'],['../interface_t_n_k_traffic_jam_info.html#a9f4b94833575b0b0606822b8081c0084',1,'TNKTrafficJamInfo::routePoints()'],['../interface_t_n_k_walk_route.html#a7b14a86193d5329fd1912f119902fb0d',1,'TNKWalkRoute::routePoints()']]],
  ['routepointsisreroutesearch_27',['routePointsIsReRouteSearch',['../interface_t_n_k_drive_route_search_option.html#a1fb61bf69dbf9424250acd9e553719e3',1,'TNKDriveRouteSearchOption']]],
  ['routepointsissearch_28',['routePointsIsSearch',['../interface_t_n_k_drive_route_search_option.html#affed1513cbc0717680539f027b9be230',1,'TNKDriveRouteSearchOption']]],
  ['routepointslocations_29',['routePointsLocations',['../interface_t_n_k_drive_route_search_option.html#ac080ed83fddd7bdb6accd7578931a61d',1,'TNKDriveRouteSearchOption']]],
  ['routes_30',['routes',['../interface_t_n_k_drive_route_search_result.html#a8ef0c0261e441f9108b0b6e8f997a150',1,'TNKDriveRouteSearchResult::routes()'],['../interface_t_n_k_ride_route_search_result.html#ae9ac880da356fd3a1fd25e72e1e3772f',1,'TNKRideRouteSearchResult::routes()'],['../interface_t_n_k_walk_route_search_result.html#aa8df575cd9c98bd1ba4b23fbc5322082',1,'TNKWalkRouteSearchResult::routes()']]],
  ['routetrafficitems_31',['routeTrafficItems',['../interface_t_n_k_drive_route.html#a70f241a0d81d5e518f5f3bb05bde7a09',1,'TNKDriveRoute']]],
  ['routetrafficlighthidden_32',['routeTrafficLightHidden',['../interface_t_n_k_drive_nav_view.html#a319172c4389768eaea40497ac10fa3bb',1,'TNKDriveNavView::routeTrafficLightHidden()'],['../interface_t_n_k_travel_nav_view.html#ab00a5d3bdb8cca1315797bb8bff14644',1,'TNKTravelNavView::routeTrafficLightHidden()']]],
  ['running_33',['running',['../interface_t_n_k_base_nav_manager.html#aefc6f278f748cf4c8d61a25c5095cdc3',1,'TNKBaseNavManager']]]
];
